
from wedoc.api import document
from wedoc.api import spreadsheet
from wedoc.api.client import WedocClientBase


class WedocClient(WedocClientBase):
    doc = document.Document()
    wb = spreadsheet.Spreadsheet()

    def __init__(self, corpid, corpsecret) -> None:
        super().__init__(corpid, corpsecret)



from wedoc.api.client import WedocClientBase

class Spreadsheet(WedocClientBase):
    def __init__(self) -> None:
        pass

    def get_sheet_properties(self, docid):
        """获取表格行列信息"""
        api = "/wedoc/spreadsheet/get_sheet_properties"
        pyload = {"docid": docid}
        res = self.request("post", api, pyload)
        return res

    def get_sheet_range_data(self, docid, sheet_id, range):
        """获取表格数据"""
        api = "/wedoc/spreadsheet/get_sheet_range_data"
        pyload = {"docid": docid, "sheet_id": sheet_id, "range": range}
        res = self.request("post", api, pyload)
        return res

    def batch_update(self, docid):
        """编辑表格内容"""
        api = "/wedoc/spreadsheet/get_sheet_range_data"
        pyload = {
            "docid": docid,
            "requests": [
                {"add_sheet_request": {...}},
                {"update_range_request": {...}},
                {"delete_dimension_request": {...}},
                {"delete_sheet_request": {...}},
            ],
        }
        res = self.request("post", api, pyload)
        return res



from wedoc.api.client import WedocClientBase


class Document(WedocClientBase):
    def __init__(self) -> None:
        pass

    def create_doc(self, doc_name, doc_type, spaceid="", fatherid="", admin_users=[]):
        """创建文档"""
        api = "/wedoc/create_doc"
        pyload = {
            "doc_type": doc_type,
            "doc_name": doc_name,
        }

        res = self.request("post", api, pyload)
        return res

    def rename_doc(self, docid, new_name):
        """重命名文档"""
        api = "/wedoc/rename_doc"
        pyload = {"docid": docid, "new_name": new_name}
        res = self.request("post", api, pyload)
        return res

    def del_doc(self, docid):
        """删除文档"""
        api = "/wedoc/del_doc"
        pyload = {"docid": docid}
        res = self.request("post", api, pyload)
        return res

    def get_doc_base_info(self, docid):
        """获取文档基础信息"""
        api = "/wedoc/get_doc_base_info"
        pyload = {"docid": docid}
        res = self.request("post", api, pyload)
        return res
